print_readable/save_out_readable changed:
[ocaml-csv.git] / csv.mli
diff --git a/csv.mli b/csv.mli
index a8e570d..baf9e5c 100644 (file)
--- a/csv.mli
+++ b/csv.mli
@@ -1,6 +1,6 @@
 (** csv.mli - comma separated values parser
   *
-  * $Id: csv.mli,v 1.6 2005-11-25 14:06:58 rich Exp $
+  * $Id: csv.mli,v 1.7 2005-11-25 14:08:46 rich Exp $
   *)
 
 type t = string list list
@@ -69,7 +69,7 @@ val square : t -> t
 (** Make the CSV data "square" (actually rectangular).  This pads out
   * each row with empty cells so that all rows are the same length as
   * the longest row.  After this operation, every row will have length
-  * {!columns}.
+  * {!Csv.columns}.
   *)
 
 val is_square : t -> bool
@@ -133,7 +133,7 @@ val associate : string list -> t -> (string * string) list list
   *     etc. ]
   * v}
   *
-  * Each row is turned into an assoc list (see {!List.assoc}).
+  * Each row is turned into an assoc list (see [List.assoc]).
   *
   * If a row is too short, it is padded with empty cells ([""]).  If
   * a row is too long, it is truncated.
@@ -161,9 +161,10 @@ val save : ?separator:char -> string -> t -> unit
 val print_readable : t -> unit
 (** Print the CSV data to [stdout] in a human-readable format.  Not much
   * is guaranteed about how the CSV is printed, except that it will be
* easier to follow than a "raw" output done with {!print}.  This is
   * a one-way operation.  There is no easy way to parse the output of
   * this command back into CSV data.
   *)
 val save_out_readable : out_channel -> t -> unit
-(** As for {!print_readable}, allowing the output to be sent to a channel. *)
+(** As for {!Csv.print_readable}, allowing the output to be sent to a channel.
+  *)
@@ -161,9 +161,10 @@ val save : ?separator:char -> string -> t -> unit
 (** Print the CSV data to [stdout] in a human-readable format.  Not much
   * is guaranteed about how the CSV is printed, except that it will be
-  * easier to follow than a "raw" output done with {!print}.  This is
+  * easier to follow than a "raw" output done with {!Csv.print}.  This is
   * a one-way operation.  There is no easy way to parse the output of
   * this command back into CSV data.